#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['configstore', 'configstore.backends']

package_data = \
{'': ['*']}

extras_require = \
{'awsssm': ['boto3'], 'dotenv': ['django-dotenv']}

setup(name='configstore',
      version='0.6.1',
      description='Retrieve settings and secrets from different storages.',
      author='Caravan Coop',
      author_email='hi@caravan.coop',
      url='https://github.com/caravancoop/configstore',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
     )
